@@ -9,14 +9,14 @@ Ex:
 >>>     class __metaclass__(FilterMeta):
 >>>         pass
 
->>> Class B(A):
+>>> class B(A):
 >>>     @classmethod
->>>     def filter(cls, web_socket_instance):
+>>>     def filter(cls, web_socket_instance, data):
 >>>        print("foo")
 
->>> Class C(A):
+>>> class C(A):
 >>>     @classmethod
->>>     def filter(cls, web_socket_instance):
+>>>     def filter(cls, web_socket_instance, data):
 >>>         print("bar")
 
 >>> A.run(web_socket_instance)
@@ -63,3 +63,11 @@ class WebSocketDisconnectFilter(FilterBase):
 
     class __metaclass__(FilterMeta):
         pass
+
+
+class WebSocketConsumerFilter(FilterBase):
+    """
+    Chain called on any data existing in web_socket_instance.queue.
+    """
+    class __metaclass__(FilterMeta):
+        pass
